@@ -40,7 +40,7 @@ use XSLoader;
 use English '-no_match_vars';
 use POSIX qw<F_SETFD F_GETFD FD_CLOEXEC>;
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 use constant DOM_TYPE_ELEMENT => 1;
 use constant ORDERED_NODE_SNAPSHOT_TYPE => 7;
@@ -125,6 +125,18 @@ has prompt_answers => (
     default => sub { [] },
 );
 
+has confirm_answers => (
+    is      => 'rw',
+    isa     => 'ArrayRef',
+    default => sub { [] },
+);
+
+has accept_confirm => (
+    is      => 'rw',
+    isa     => 'Bool',
+    default => 1,
+);
+
 has display => (
     is        => 'ro',
     isa       => 'X11::Xlib',
@@ -217,14 +229,14 @@ sub init_webkit {
     });
     $self->view->signal_connect('script-confirm' => sub {
         push @{ $self->confirmations }, $_[2];
-        WWW::WebKit::XSHelper::set_int_return_value($_[3], TRUE);
+        WWW::WebKit::XSHelper::set_int_return_value($_[3],
+            @{ $self->confirm_answers }
+                ? pop @{ $self->confirm_answers }
+                : ($self->accept_confirm ? TRUE : FALSE));
         return TRUE;
     });
     $self->view->signal_connect('script-prompt' => sub {
-        # warn 'prompt: ' . $_[2];
-        # warn "answering with: " . $self->prompt_answers->[-1];
-        #FIXME causes segfault:
-        # WWW::WebKit::XSHelper::set_string_return_value($_[4], pop @{ $self->prompt_answers });
+        WWW::WebKit::XSHelper::set_string_return_value($_[4], pop @{ $self->prompt_answers });
         return TRUE;
     });
     $self->view->signal_connect('console-message' => sub {
@@ -290,7 +302,7 @@ sub setup_xvfb {
     }
 
     # restore STDERR
-    open STDERR, '>&', $stderr;
+    open STDERR, '>&', $stderr or die "Can't open STDERR: $!";;
 
     pipe my $read, my $write;
     my $writefd = fileno $write;
@@ -301,11 +313,11 @@ sub setup_xvfb {
     $flags &= ~FD_CLOEXEC;
     fcntl $write, F_SETFD, $flags;
 
-    open STDERR, '>/dev/null';
+    open STDERR, '>', '/dev/null' or die "Cant' open STDERR: $!";
 
     system ("Xvfb -nolisten tcp -terminate -screen 0 1600x1200x24 -displayfd $writefd &");
 
-    open STDERR, '>&', $stderr;
+    open STDERR, '>&', $stderr or die "Can't open STDERR: $!";
 
     # Xvfb prints the display number newline terminated to our pipe
     my $display = <$read>;
@@ -692,24 +704,6 @@ sub type_keys {
     return 1;
 }
 
-=head3 delete_text($locator)
-
-Delete text in elements where contenteditable="true".
-
-=cut
-
-sub delete_text {
-    my ($self, $locator) = @_;
-
-    my $element = $self->resolve_locator($locator) or return;
-
-    while ($self->get_text($locator)) {
-        $self->key_press($locator, '\127', $element); # Delete
-    };
-
-    return 1;
-}
-
 sub is_upper_case {
     my ($self, $char) = @_;
 
@@ -952,6 +946,16 @@ sub get_confirmation {
     return pop @{ $self->confirmations };
 }
 
+=head3 get_alert()
+
+=cut
+
+sub get_alert {
+    my ($self) = @_;
+
+    return pop @{ $self->alerts };
+}
+
 =head3 print_requested()
 
 =cut
@@ -962,6 +966,16 @@ sub print_requested {
     return pop @{ $self->print_requests } ? 1 : 0;
 }
 
+=head3 answer_on_next_confirm
+
+=cut
+
+sub answer_on_next_confirm {
+    my ($self, $answer) = @_;
+
+    push @{ $self->confirm_answers }, $answer;
+}
+
 =head3 answer_on_next_prompt($answer)
 
 =cut
@@ -1204,6 +1218,24 @@ sub disable_plugins {
     $self->view->set_settings($settings);
 }
 
+=head3 delete_text($locator)
+
+Delete text in elements where contenteditable="true".
+
+=cut
+
+sub delete_text {
+    my ($self, $locator) = @_;
+
+    my $element = $self->resolve_locator($locator) or return;
+
+    while ($self->get_text($locator)) {
+        $self->key_press($locator, '\127', $element); # Delete
+    };
+
+    return 1;
+}
+
 1;
 
 =head1 SEE ALSO
